django-docfield-couchdb
=======================

Django fields for representing CouchDB docs other idioms.
---------------------------------------------------------

Django fields and other add-ons that represent key CouchDB data structures:

* Docs, which can authoratively reside in either Couch or your Django RDBMS
* Arbitrary JSON subtrees
* CouchDB _id and _rev identifiers
* NEW in 1.1: an error-free setup.py install experience!

And MORE! Coming soon of course. (next up, JSON diff views and widgets!)